@@ -5,10 +5,7 @@ from datetime import datetime
 from datetime import timedelta
 from httplib import BadStatusLine
 from HTMLParser import HTMLParseError
-from urllib2 import HTTPError
-from urllib2 import URLError
-from urllib2 import urlopen
-from urllib2 import Request as urllib2Request
+import urllib2
 
 from django.conf import settings
 from django.utils.importlib import import_module
@@ -26,7 +23,7 @@ from linkcheck_settings import EXTERNAL_RECHECK_INTERVAL
 
 EXTERNAL_REGEX = re.compile(EXTERNAL_REGEX_STRING)
 
-class HeadRequest(urllib2Request):
+class HeadRequest(urllib2.Request):
     def get_method(self):
         return "HEAD"
 
@@ -77,6 +74,14 @@ class Url(models.Model):
     def external(self):
         return EXTERNAL_REGEX.match(self.url)
 
+    def url_unquoted(self):
+        try:
+            # URLs should be ascii encodable
+            url = self.url.encode('ascii')
+        except UnicodeEncodeError:
+            url = self.url
+        return urllib2.unquote(url).decode('utf8')
+
     def check(self, check_internal=True, check_external=True, external_recheck_interval=EXTERNAL_RECHECK_INTERVAL):
 
         from linkcheck.utils import LinkCheckHandler
@@ -87,7 +92,7 @@ class Url(models.Model):
         # They shouldn't generally exist but occasionally slip through
         # If settings.SITE_DOMAINS isn't set then use settings.SITE_DOMAIN
         # but also check for variants: example.org, www.example.org, test.example.org
-        
+
         original_url = None # used to restore the original url afterwards
 
         if SITE_DOMAINS: #if the setting is present
@@ -100,7 +105,7 @@ class Url(models.Model):
             elif root_domain.startswith('test.'):
                 root_domain = root_domain[5:]
             internal_exceptions = ['http://'+root_domain, 'http://www.'+root_domain, 'http://test.'+root_domain]
-            
+
         for ex in internal_exceptions:
             if ex and self.url.startswith(ex):
                 original_url = self.url
@@ -119,13 +124,16 @@ class Url(models.Model):
                 self.message = 'Link to within the same page (not automatically checked)'
 
             elif self.url.startswith(MEDIA_PREFIX):
-                if os.path.exists(settings.MEDIA_ROOT+self.url[len(MEDIA_PREFIX)-1:]): #TODO Assumes a direct mapping from media url to local filesystem path. This will break quite easily for alternate setups
+                #TODO Assumes a direct mapping from media url to local filesystem path. This will break quite easily for alternate setups
+                if os.path.exists(settings.MEDIA_ROOT + self.url_unquoted()[len(MEDIA_PREFIX)-1:]):
                     self.message = 'Working file link'
                     self.status = True
                 else:
                     self.message = 'Missing Document'
 
             elif self.url.startswith('/'):
+                old_prepend_setting = settings.PREPEND_WWW
+                settings.PREPEND_WWW = False
                 c = Client()
                 c.handler = LinkCheckHandler()
                 response = c.get(self.url, follow=True)
@@ -151,6 +159,7 @@ class Url(models.Model):
                     self.message = 'This link redirects: code %d (not automatically checked)' % (response.status_code, )
                 else:
                     self.message = 'Broken internal link'
+                settings.PREPEND_WWW = old_prepend_setting
             else:
                 self.message = 'Invalid URL'
 
@@ -164,29 +173,29 @@ class Url(models.Model):
 
             if self.last_checked and (self.last_checked > external_recheck_datetime):
                 return self.status
-            
+
             try:
-                
+
                 # Remove URL fragment identifiers
                 url = self.url.rsplit('#')[0]
-                
+
                 if self.url.count('#'):
                     # We have to get the content so we can check the anchors
-                    response = urlopen(url)
+                    response = urllib2.urlopen(url)
                 else:
                     # Might as well just do a HEAD request
                     req = HeadRequest(url, headers={'User-Agent' : "http://%s Linkchecker" % settings.SITE_DOMAIN})
                     try:
-                        response = urlopen(req)
+                        response = urllib2.urlopen(req)
                     except ValueError:
                         # ...except sometimes it triggers a bug in urllib2
-                        response = urlopen(url)
-                        
+                        response = urllib2.urlopen(url)
+
                 self.message = ' '.join([str(response.code), response.msg])
                 self.status = True
 
                 if self.url.count('#'):
-                    
+
                     anchor = self.url.split('#')[1]
                     from linkcheck import parse_anchors
                     try:
@@ -197,7 +206,7 @@ class Url(models.Model):
                         else:
                             self.message = 'Broken external hash anchor'
                             self.status = False
-                            
+
                     except HTMLParseError:
                         # The external web page is mal-formatted
                         # I reckon a broken anchor on an otherwise good URL should count as a pass
@@ -207,13 +216,13 @@ class Url(models.Model):
             except BadStatusLine:
                     self.message = "Bad Status Line"
 
-            except HTTPError, e:
+            except urllib2.HTTPError, e:
                 if hasattr(e, 'code') and hasattr(e, 'msg'):
                     self.message = ' '.join([str(e.code), e.msg])
                 else:
                     self.message = "Unknown Error"
 
-            except URLError, e:
+            except urllib2.URLError, e:
                 if hasattr(e, 'reason'):
                     self.message = 'Unreachable: '+str(e.reason)
                 elif hasattr(e, 'code') and e.code!=301:
